# OmnivoreX

[Omnivore](https://omnivore.app/) Text User Interface (TUI) for the Omnivore API using the [OmnivoreQL](https://github.com/yazdipour/OmnivoreQL).

Do not forget to STAR and Support the project:

[![GitHub stars](https://img.shields.io/github/stars/yazdipour/omnivorex.svg?style=social&label=Star)](https://github.com/yazdipour/omnivorex/stargazers)
[![Github Sponsor](https://img.shields.io/static/v1?label=Sponsor&message=%E2%9D%A4&logo=GitHub&color=%23fe8e86)](https://github.com/sponsors/yazdipour)
[![PyPI version](https://badge.fury.io/py/omnivorex.svg)](https://pypi.org/project/omnivorex/)

## Installation

```bash
pip install omnivorex
```

## Usage

1. Get your Omnivore API Key from [here](https://dashboard.omnivore.io/developers).

2. Run the command:

```bash
omnivorex
```

## Screenshots

![OmnivoreX](/docs/screenshots/omnivorex.png)
